@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: bacon-video-widget-gst.c,v 1.82 2004/05/30 12:21:10 hadess Exp $
+ * $Id: bacon-video-widget-gst.c,v 1.84 2004/06/22 14:16:35 hadess Exp $
  *
  */
 
@@ -438,8 +438,9 @@ bacon_video_widget_class_init (BaconVideoWidgetClass * klass)
 		  G_SIGNAL_RUN_LAST,
 		  G_STRUCT_OFFSET (BaconVideoWidgetClass, error),
 		  NULL, NULL,
-		  baconvideowidget_marshal_VOID__STRING_BOOLEAN,
-		  G_TYPE_NONE, 2, G_TYPE_STRING, G_TYPE_BOOLEAN);
+		  baconvideowidget_marshal_VOID__STRING_BOOLEAN_BOOLEAN,
+		  G_TYPE_NONE, 3, G_TYPE_STRING,
+		  G_TYPE_BOOLEAN, G_TYPE_BOOLEAN);
 
   bvw_table_signals[EOS] =
     g_signal_new ("eos",
@@ -500,7 +501,7 @@ bacon_video_widget_class_init (BaconVideoWidgetClass * klass)
 }
 
 static void
-bacon_video_widget_instance_init (BaconVideoWidget * bvw)
+bacon_video_widget_init (BaconVideoWidget * bvw)
 {
   g_return_if_fail (bvw != NULL);
   g_return_if_fail (BACON_IS_VIDEO_WIDGET (bvw));
@@ -601,7 +602,8 @@ bacon_video_widget_signal_idler (BaconVideoWidget *bvw)
 
           if (emit) {
             g_signal_emit (G_OBJECT (bvw),
-                           bvw_table_signals[ERROR], 0, error_message, TRUE);
+                           bvw_table_signals[ERROR], 0,
+			   error_message, TRUE, FALSE);
             
             /* Keep a copy of the last emitted message */
             if (bvw->priv->last_error_message)
@@ -1890,32 +1892,7 @@ bacon_video_widget_get_current_frame (BaconVideoWidget * bvw)
 /*                                             */
 /* =========================================== */
 
-GType
-bacon_video_widget_get_type (void)
-{
-  static GType bacon_video_widget_type = 0;
-
-  if (!bacon_video_widget_type)
-    {
-      static const GTypeInfo bacon_video_widget_info = {
-	sizeof (BaconVideoWidgetClass),
-	(GBaseInitFunc) NULL,
-	(GBaseFinalizeFunc) NULL,
-	(GClassInitFunc) bacon_video_widget_class_init,
-	(GClassFinalizeFunc) NULL,
-	NULL /* class_data */ ,
-	sizeof (BaconVideoWidget),
-	0 /* n_preallocs */ ,
-	(GInstanceInitFunc) bacon_video_widget_instance_init,
-      };
-
-      bacon_video_widget_type = g_type_register_static
-	(GTK_TYPE_BOX, "BaconVideoWidget",
-	 &bacon_video_widget_info, (GTypeFlags) 0);
-    }
-
-  return bacon_video_widget_type;
-}
+G_DEFINE_TYPE(BaconVideoWidget, bacon_video_widget, GTK_TYPE_BOX)
 
 struct poptOption *
 bacon_video_widget_get_popt_table (void)
