@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: bacon-video-widget-xine.c,v 1.118 2004/05/30 12:21:10 hadess Exp $
+ * $Id: bacon-video-widget-xine.c,v 1.121 2004/06/22 14:16:35 hadess Exp $
  *
  * the xine engine in a widget - implementation
  */
@@ -77,19 +77,21 @@ enum {
 
 /* Enum for none-signal stuff that needs to go through the AsyncQueue */
 enum {
-	RATIO,
+	RATIO_ASYNC,
 	TITLE_CHANGE_ASYNC,
 	EOS_ASYNC,
 	CHANNELS_CHANGE_ASYNC,
 	BUFFERING_ASYNC,
 	MESSAGE_ASYNC,
-	SPEED_WARNING_ASYNC
+	SPEED_WARNING_ASYNC,
+	ERROR_ASYNC
 };
 
 typedef struct {
 	int signal;
 	char *msg;
 	int num;
+	gboolean fatal;
 } signal_data;
 
 /* Arguments */
@@ -217,7 +219,7 @@ static const char *demux_strategies_str[] = {
 };
 
 static void bacon_video_widget_class_init (BaconVideoWidgetClass *klass);
-static void bacon_video_widget_instance_init (BaconVideoWidget *bvw);
+static void bacon_video_widget_init (BaconVideoWidget *bvw);
 
 static void setup_config (BaconVideoWidget *bvw);
 
@@ -255,31 +257,7 @@ static void show_vfx_update (BaconVideoWidget *bvw, gboolean show_visuals);
 
 static int bvw_table_signals[LAST_SIGNAL] = { 0 };
 
-GType
-bacon_video_widget_get_type (void)
-{
-	static GType bacon_video_widget_type = 0;
-
-	if (!bacon_video_widget_type) {
-		static const GTypeInfo bacon_video_widget_info = {
-			sizeof (BaconVideoWidgetClass),
-			(GBaseInitFunc) NULL,
-			(GBaseFinalizeFunc) NULL,
-			(GClassInitFunc) bacon_video_widget_class_init,
-			(GClassFinalizeFunc) NULL,
-			NULL /* class_data */,
-			sizeof (BaconVideoWidget),
-			0 /* n_preallocs */,
-			(GInstanceInitFunc) bacon_video_widget_instance_init,
-		};
-
-		bacon_video_widget_type = g_type_register_static
-			(GTK_TYPE_BOX, "BaconVideoWidget",
-			 &bacon_video_widget_info, (GTypeFlags)0);
-	}
-
-	return bacon_video_widget_type;
-}
+G_DEFINE_TYPE(BaconVideoWidget, bacon_video_widget, GTK_TYPE_BOX)
 
 static void
 bacon_video_widget_class_init (BaconVideoWidgetClass *klass)
@@ -340,8 +318,9 @@ bacon_video_widget_class_init (BaconVideoWidgetClass *klass)
 				G_SIGNAL_RUN_LAST,
 				G_STRUCT_OFFSET (BaconVideoWidgetClass, error),
 				NULL, NULL,
-				baconvideowidget_marshal_VOID__STRING_BOOLEAN,
-				G_TYPE_NONE, 2, G_TYPE_STRING, G_TYPE_BOOLEAN);
+				baconvideowidget_marshal_VOID__STRING_BOOLEAN_BOOLEAN,
+				G_TYPE_NONE, 3, G_TYPE_STRING, G_TYPE_BOOLEAN,
+				G_TYPE_BOOLEAN);
 
 	bvw_table_signals[EOS] =
 		g_signal_new ("eos",
@@ -407,7 +386,7 @@ bacon_video_widget_class_init (BaconVideoWidgetClass *klass)
 }
 
 static void
-bacon_video_widget_instance_init (BaconVideoWidget *bvw)
+bacon_video_widget_init (BaconVideoWidget *bvw)
 {
 	const char *const *autoplug_list;
 	int i = 0;
@@ -557,7 +536,7 @@ frame_output_cb (void *bvw_gen,
 			signal_data *data;
 
 			data = g_new0 (signal_data, 1);
-			data->signal = RATIO;
+			data->signal = RATIO_ASYNC;
 			g_async_queue_push (bvw->priv->queue, data);
 			g_idle_add ((GSourceFunc)
 					bacon_video_widget_idle_signal, bvw);
@@ -1169,20 +1148,27 @@ bacon_video_widget_realize (GtkWidget *widget)
 			(gdk_display_get_default ()));
 	bvw->priv->screen = DefaultScreen (bvw->priv->display);
 
-	bvw->priv->ao_driver = load_audio_out_driver (bvw, NULL);
-	bvw->priv->vo_driver = load_video_out_driver (bvw, bvw->priv->null_out);
+	bvw->priv->vo_driver = load_video_out_driver
+		(bvw, bvw->priv->null_out);
 
 	if (bvw->priv->vo_driver == NULL)
 	{
+		signal_data *sigdata;
+
 		bvw->priv->vo_driver = load_video_out_driver (bvw, TRUE);
-		g_signal_emit (G_OBJECT (bvw),
-				bvw_table_signals[ERROR], 0,
-				_("No video output is available. Make sure that the program is correctly installed."), TRUE);
-		g_message ("error");
+
+		/* We need to use an async signal, otherwise we try to
+		 * unrealize the widget before it's finished realizing */
+		sigdata = g_new0 (signal_data, 1);
+		sigdata->signal = ERROR_ASYNC;
+		sigdata->msg = _("No video output is available. Make sure that the program is correctly installed.");
+		sigdata->fatal = TRUE;
+		g_async_queue_push (bvw->priv->queue, sigdata);
+		g_idle_add ((GSourceFunc) bacon_video_widget_idle_signal, bvw);
 	}
-	//FIXME
+
+	bvw->priv->ao_driver = load_audio_out_driver (bvw, NULL);
 
-	g_assert (bvw->priv->vo_driver != NULL);
 	setup_config_video (bvw);
 
 	if (bvw->priv->null_out == FALSE && bvw->priv->ao_driver != NULL)
@@ -1225,7 +1211,7 @@ bacon_video_widget_idle_signal (BaconVideoWidget *bvw)
 
 	switch (data->signal)
 	{
-	case RATIO:
+	case RATIO_ASYNC:
 		bacon_video_widget_set_scale_ratio (bvw, 1);
 		break;
 	case TITLE_CHANGE_ASYNC:
@@ -1249,13 +1235,17 @@ bacon_video_widget_idle_signal (BaconVideoWidget *bvw)
 	case MESSAGE_ASYNC:
 		g_signal_emit (G_OBJECT (bvw),
 				bvw_table_signals[ERROR],
-				0, data->msg, TRUE);
+				0, data->msg, TRUE, FALSE);
 		break;
 	case SPEED_WARNING_ASYNC:
 		g_signal_emit (G_OBJECT (bvw),
 				bvw_table_signals[SPEED_WARNING],
 				0, NULL);
 		break;
+	case ERROR_ASYNC:
+		g_signal_emit (G_OBJECT (bvw),
+				bvw_table_signals[ERROR], 0,
+				data->msg, TRUE, data->fatal);
 	default:
 		g_assert_not_reached ();
 	}
@@ -1284,7 +1274,7 @@ xine_event_message (BaconVideoWidget *bvw, xine_ui_message_data_t *data)
 	case XINE_MSG_GENERAL_WARNING:
 		break;
 	case XINE_MSG_UNKNOWN_HOST:
-		message = g_strdup_printf (_("The server you are trying to connect to is not known."));
+		message = g_strdup (_("The server you are trying to connect to is not known."));
 		break;
 	case XINE_MSG_UNKNOWN_DEVICE:
 		message = g_strdup_printf (_("The device name you specified (%s) seems to be invalid."), (char *) data + data->parameters);
@@ -1293,13 +1283,13 @@ xine_event_message (BaconVideoWidget *bvw, xine_ui_message_data_t *data)
 		message = g_strdup_printf (_("The server you are trying to connect to (%s) is unreachable."), (char *) data + data->parameters);
 		break;
 	case XINE_MSG_CONNECTION_REFUSED:
-		message = g_strdup_printf (_("The connection to this server was refused."));
+		message = g_strdup (_("The connection to this server was refused."));
 		break;
 	case XINE_MSG_FILE_NOT_FOUND:
-		message = g_strdup_printf (_("The specified movie '%s' could not be found."), (char *) data + data->parameters);
+		message = g_strdup (_("The specified movie could not be found."));
 		break;
 	case XINE_MSG_READ_ERROR:
-		message = g_strdup_printf (_("The movie '%s' could not be read."), (char *) data + data->parameters);
+		message = g_strdup (_("The movie could not be read."));
 		break;
 	case XINE_MSG_LIBRARY_LOAD_ERROR:
 		message = g_strdup_printf (_("A problem occured while loading a library or a decoder (%s)."), (char *) data + data->parameters);
@@ -1432,7 +1422,7 @@ xine_error (BaconVideoWidget *bvw, GError **error)
 
 	if (save_data != NULL)
 	{
-		g_set_error (error, 0, 0, save_data->msg);
+		g_set_error (error, 0, 0, "%s", save_data->msg);
 		g_free (save_data->msg);
 		g_free (save_data);
 
