@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: bacon-video-widget.h,v 1.43 2004/05/10 00:47:56 hadess Exp $
+ * $Id: bacon-video-widget.h,v 1.44 2004/06/22 14:16:35 hadess Exp $
  *
  * the xine engine in a widget - header
  */
@@ -45,7 +45,7 @@ typedef struct {
 	GtkBoxClass parent_class;
 
 	void (*error) (GtkWidget *bvw, const char *message,
-                       gboolean playback_stopped);
+                       gboolean playback_stopped, gboolean fatal);
 	void (*eos) (GtkWidget *bvw);
 	void (*got_metadata) (GtkWidget *bvw);
 	void (*title_change) (GtkWidget *bvw, const char *title);
