@@ -24,6 +24,7 @@
 #include "totem-playlist.h"
 
 #include <gtk/gtk.h>
+#include <glib/gi18n.h>
 #include <gdk/gdkkeysyms.h>
 #include <glade/glade.h>
 #include <gconf/gconf-client.h>
@@ -34,23 +35,6 @@
 #include "totem-pl-parser.h"
 #include "debug.h"
 
-#ifdef HAVE_GTK_ONLY
-#ifdef ENABLE_NLS
-#include <libintl.h>
-#define _(String) dgettext(GETTEXT_PACKAGE,String)
-#ifdef gettext_noop
-#define N_(String) gettext_noop(String)
-#else
-#define N_(String) (String)
-#endif /* gettext_noop */
-#else
-#define _(String) (String)
-#define N_(String) (String)
-#endif /* ENABLE_NLS */
-#else
-#include <libgnome/gnome-i18n.h>
-#endif /* HAVE_GTK_ONLY */
-
 #define PL_LEN (gtk_tree_model_iter_n_children (playlist->_priv->model, NULL))
 
 static void ensure_shuffled (TotemPlaylist *playlist, gboolean shuffle);
@@ -129,33 +113,10 @@ static void totem_playlist_class_init (TotemPlaylistClass *class);
 static void totem_playlist_init       (TotemPlaylist      *playlist);
 
 static void init_treeview (GtkWidget *treeview, TotemPlaylist *playlist);
-static gboolean totem_playlist_unset_playing (TotemPlaylist *playlist);
 
-GtkType
-totem_playlist_get_type (void)
-{
-	static GtkType totem_playlist_type = 0;
+#define totem_playlist_unset_playing(x) totem_playlist_set_playing(x, FALSE)
 
-	if (!totem_playlist_type) {
-		static const GTypeInfo totem_playlist_info = {
-			sizeof (TotemPlaylistClass),
-			(GBaseInitFunc) NULL,
-			(GBaseFinalizeFunc) NULL,
-			(GClassInitFunc) totem_playlist_class_init,
-			(GClassFinalizeFunc) NULL,
-			NULL /* class_data */,
-			sizeof (TotemPlaylist),
-			0 /* n_preallocs */,
-			(GInstanceInitFunc) totem_playlist_init,
-		};
-
-		totem_playlist_type = g_type_register_static (GTK_TYPE_DIALOG,
-				"TotemPlaylist", &totem_playlist_info,
-				(GTypeFlags)0);
-	}
-
-	return totem_playlist_type;
-}
+G_DEFINE_TYPE(TotemPlaylist, totem_playlist, GTK_TYPE_DIALOG)
 
 /* Helper functions */
 static gboolean
@@ -574,9 +535,9 @@ selection_changed (GtkTreeSelection *treeselection, TotemPlaylist *playlist)
 	gtk_widget_set_sensitive (down_button, sensitivity);
 }
 
-/* This function checks if the current item is NULL, and try to update it as the
- * first item of the playlist if so. It returns TRUE if there is a current
- * item */
+/* This function checks if the current item is NULL, and try to update it
+ * as the first item of the playlist if so. It returns TRUE if there is a
+ * current item */
 static gboolean
 update_current_from_playlist (TotemPlaylist *playlist)
 {
@@ -1161,7 +1122,7 @@ typedef struct {
 	int random;
 	int index;
 } RandomData;
-                                                                                
+
 static int
 compare_random (gconstpointer ptr_a, gconstpointer ptr_b)
 {
@@ -1565,7 +1526,7 @@ totem_playlist_add_mrl (TotemPlaylist *playlist, const char *mrl,
 {
 	g_return_val_if_fail (mrl != NULL, FALSE);
 
-	if (totem_pl_parser_parse (playlist->_priv->parser, mrl) == FALSE)
+	if (totem_pl_parser_parse (playlist->_priv->parser, mrl, TRUE) != TOTEM_PL_PARSER_RESULT_SUCCESS)
 		return totem_playlist_add_one_mrl (playlist, mrl, display_name);
 	return TRUE;
 }
@@ -1731,8 +1692,7 @@ totem_playlist_set_playing (TotemPlaylist *playlist, gboolean state)
 			&iter,
 			playlist->_priv->current);
 
-	if (&iter == NULL)
-		return FALSE;
+	g_return_val_if_fail (&iter != NULL, FALSE);
 
 	if (state != FALSE)
 		gtk_list_store_set (store, &iter,
@@ -1745,29 +1705,6 @@ totem_playlist_set_playing (TotemPlaylist *playlist, gboolean state)
 	return TRUE;
 }
 
-static gboolean
-totem_playlist_unset_playing (TotemPlaylist *playlist)
-{
-	GtkListStore *store;
-	GtkTreeIter iter;
-
-	if (update_current_from_playlist (playlist) == FALSE)
-		return FALSE;
-
-	store = GTK_LIST_STORE (playlist->_priv->model);
-	gtk_tree_model_get_iter (playlist->_priv->model,
-			&iter,
-			playlist->_priv->current);
-
-	if (&iter == NULL)
-		return FALSE;
-
-	gtk_list_store_set (store, &iter,
-			PIX_COL, NULL,
-			-1);
-	return TRUE;
-}
-
 void
 totem_playlist_set_previous (TotemPlaylist *playlist)
 {
