@@ -21,6 +21,7 @@
 #define __TOTEM_PRIVATE_H__
 
 #include <glade/glade.h>
+#include <glib/gi18n.h>
 #include "totem-remote.h"
 #include "scrsaver.h"
 #include "egg-recent-model.h"
@@ -29,23 +30,6 @@
 #include "bacon-message-connection.h"
 #include "bacon-video-widget.h"
 
-#ifdef HAVE_GTK_ONLY
-#ifdef ENABLE_NLS
-#include <libintl.h>
-#define _(String) dgettext(GETTEXT_PACKAGE,String)
-#ifdef gettext_noop
-#define N_(String) gettext_noop(String)
-#else
-#define N_(String) (String)
-#endif /* gettext_noop */
-#else
-#define _(String) (String)
-#define N_(String) (String)
-#endif /* ENABLE_NLS */
-#else
-#include <libgnome/gnome-i18n.h>
-#endif /* HAVE_GTK_ONLY */
-
 typedef enum {
 	TOTEM_CONTROLS_VISIBLE,
 	TOTEM_CONTROLS_HIDDEN,
