@@ -31,23 +31,7 @@
 #include <gtk/gtklabel.h>
 #include <gtk/gtkvseparator.h>
 #include <gtk/gtkwindow.h>
-
-#ifdef HAVE_GTK_ONLY
-#ifdef ENABLE_NLS
-#include <libintl.h>
-#define _(String) dgettext(GETTEXT_PACKAGE,String)
-#ifdef gettext_noop
-#define N_(String) gettext_noop(String)
-#else
-#define N_(String) (String)
-#endif /* gettext_noop */
-#else
-#define _(String) (String)
-#define N_(String) (String)
-#endif /* ENABLE_NLS */
-#else
-#include <libgnome/gnome-i18n.h>
-#endif /* HAVE_GTK_ONLY */
+#include <glib/gi18n.h>
 
 #include "totem-statusbar.h"
 
@@ -96,32 +80,7 @@ static char
   return NULL;
 }
 
-GType      
-totem_statusbar_get_type (void)
-{
-  static GType statusbar_type = 0;
-
-  if (!statusbar_type)
-    {
-      static const GTypeInfo statusbar_info =
-      {
-        sizeof (TotemStatusbarClass),
-	NULL,		/* base_init */
-	NULL,		/* base_finalize */
-        (GClassInitFunc) totem_statusbar_class_init,
-	NULL,		/* class_finalize */
-	NULL,		/* class_data */
-        sizeof (TotemStatusbar),
-	0,		/* n_preallocs */
-        (GInstanceInitFunc) totem_statusbar_init,
-      };
-
-      statusbar_type = g_type_register_static (GTK_TYPE_HBOX, "TotemStatusbar",
-					       &statusbar_info, 0);
-    }
-
-  return statusbar_type;
-}
+G_DEFINE_TYPE(TotemStatusbar, totem_statusbar, GTK_TYPE_HBOX)
 
 static void
 totem_statusbar_class_init (TotemStatusbarClass *class)
